#
# spec file for package htdig
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define apache_serverroot %(%{_sbindir}/apxs2 -q datadir 2>/dev/null || %{_sbindir}/apxs2 -q PREFIX)
Name:           htdig
Version:        3.2.0b6
Release:        lp152.3.7
Summary:        WWW Index and Search System
License:        GPL-2.0+
Group:          Productivity/Networking/Web/Utilities
Url:            http://www.htdig.org
Source:         http://switch.dl.sourceforge.net/sourceforge/htdig/htdig-%{version}.tar.bz2
Source1:        %{name}-README.SUSE
Patch1:         %{name}-google-style.patch
Patch2:         %{name}-rundig.patch
Patch3:         %{name}-ExternalParser-typo.patch
Patch4:         %{name}-SSLConnection.patch
Patch5:         %{name}-simpleUTF8.patch
Patch8:         %{name}-cleanup-db.diff
Patch9:         %{name}-cross-site-CAN-2005-0085.patch
Patch10:        %{name}-3.2.0b6-strictaliasing.diff
Patch11:        htsearch-gcc41.patch
Patch14:        %{name}-quoting.patch
# PATCH-FIX-UPSTREAM gmtime-lastday.patch use INT32_MAX to define last day (bnc##231196), related to (bnc#343913)
Patch15:        %{name}-gmtime-lastday.patch
# PATCH-FIX-UPSTREAM htdig-unsigned-char.patch dimstar@opensuse.org -- use unsigned char to be sure we can store values up to (int)255
Patch16:        %{name}-unsigned-char.patch
Patch17:        htdig-gcc7.patch
BuildRequires:  apache2-devel
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libapr-util1-devel
BuildRequires:  libopenssl-devel
BuildRequires:  libtool
BuildRequires:  pcre-devel
BuildRequires:  postfix
BuildRequires:  rrdtool
BuildRequires:  zlib-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The ht://Dig system is a complete World Wide Web index and search
system for a small domain or intranet. This system is not meant to
replace the need for powerful Internet-wide search systems like Lycos,
Infoseek, Webcrawler, or AltaVista. Instead it is meant to cover the
search needs of a single company, campus, or even a particular
subsection of a Web site.

Unlike some WAIS-based or Web server-based search engines, ht://Dig can
span several Web servers at a site. The type of these Web servers does
not matter as long as they understand the HTTP 1.0 protocol.

%package devel
Summary:        Development files for htdig
Group:          Development/Languages/C and C++
Requires:       %{name} = %{version}

%description devel
The ht://Dig system is a complete World Wide Web index and search
system for a small domain or intranet. This system is not meant to
replace the need for powerful Internet-wide search systems like Lycos,
Infoseek, Webcrawler, or AltaVista. Instead it is meant to cover the
search needs of a single company, campus, or even a particular
subsection of a Web site.

This package is needed if you want to develop other applications on
htdig.

%package doc
Summary:        WWW Index and Search System Documentation
Group:          Productivity/Networking/Web/Utilities
Requires:       %{name} = %{version}

%description doc
The ht://Dig system is a complete World Wide Web index and search
system for a small domain or intranet. This system is not meant to
replace the need for powerful Internet-wide search systems like Lycos,
Infoseek, Webcrawler, or AltaVista. Instead it is meant to cover the
search needs of a single company, campus, or even a particular
subsection of a Web site.

This package provides additional documentation for htdig in
%{_docdir}/htdig/

%prep
%setup -q
cp %{SOURCE1} README.SUSE
%patch1
%patch2
%patch3
%patch4
%patch5
%patch8 -p 1
%patch9 -p1
%patch10 -p1
%patch11
%patch14 -p1
%patch15
%patch16 -p1
%patch17 -p1
%build
%{?suse_update_config:%{suse_update_config -f db/dist}}
pushd contrib 1>/dev/null
find . -type f | xargs -n 1 sed -i "s@%{_prefix}/local/bin/perl@%{_bindir}/perl@"
popd 1>/dev/null
rm -f acconfig.h db/dist/acconfig.h aclocal.m4 configure db/dist/configure
autoreconf --force --install
%configure \
   --with-config-dir=%{_sysconfdir}/htdig \
   --with-common-dir=%{apache_serverroot}/htdig/common \
   --with-database-dir=%{_localstatedir}/lib/htdig/db \
   --with-cgi-bin-dir=%{apache_serverroot}/cgi-bin \
   --with-image-dir=%{apache_serverroot}/htdig/images \
   --with-image-url-prefix=images \
   --with-search-dir=%{apache_serverroot}/htdig \
   --with-ssl \
   --with-zlib \
   --enable-bigfile \
   --disable-static
make %{?_smp_mflags}

%install
find . -name \*.orig -o -name .cvsignore | xargs rm  -f
make DESTDIR=%{buildroot} install %{?_smp_mflags}
# remove static libs as nobody uses them
find %{buildroot}/%{_libdir}/ -name *.*a | xargs rm  -f
pushd %{buildroot}/%{_sysconfdir}/htdig 1>/dev/null
# try to use only one mime.types file (from aaa_base) for the distri
rm mime.types
ln -s ../mime.types mime.types
# adapt the htdig.conf file
sed -e "s@start_url:.*http://www.htdig.org/@start_url:      http://localhost/@g" htdig.conf > htdig.conf.new
mv htdig.conf.new htdig.conf
popd 1>/dev/null
# install the documentation files in the right directory
mkdir -p %{buildroot}/%{_defaultdocdir}/%{name}/
pushd %{_builddir}/%{name}-%{version} 1>/dev/null
cp -a contrib %{buildroot}/%{_defaultdocdir}/%{name}/
cp -a htdoc %{buildroot}/%{_defaultdocdir}/%{name}/
cp COPYING ChangeLog README* STATUS %{buildroot}/%{_defaultdocdir}/%{name}/

%files devel
%defattr(-,root,root)
%dir %{_includedir}/htdig
%dir %{_includedir}/htdig_db
%{_includedir}/htdig/*
%{_includedir}/htdig_db/*

%files doc
%defattr(-,root,root)
%doc %{_defaultdocdir}/%{name}/contrib
%doc %{_defaultdocdir}/%{name}/htdoc
#disable execute permission
%attr(644, root, root) %{_defaultdocdir}/%{name}/htdoc/cf_generate.pl
#delete Makefile waste from doc
%exclude %{_defaultdocdir}/%{name}/htdoc/Makefile*

%files
%defattr(-,root,root)
%dir %{_defaultdocdir}/%{name}
%doc %{_defaultdocdir}/%{name}/*
%exclude %{_defaultdocdir}/%{name}/contrib
%exclude %{_defaultdocdir}/%{name}/htdoc
%config(noreplace) %{_sysconfdir}/htdig
%dir %{apache_serverroot}/htdig
%{apache_serverroot}/htdig/search.html
%{apache_serverroot}/htdig/common
%{apache_serverroot}/htdig/images
%dir %{_localstatedir}/lib/htdig
%{_localstatedir}/lib/htdig/db
%{apache_serverroot}/cgi-bin/htsearch
%{apache_serverroot}/cgi-bin/qtest
%{_mandir}/*/*
%{_libdir}/h*
%{_bindir}/*

%changelog
* Tue Apr  4 2017 crrodriguez@opensuse.org
-  htdig-gcc7.patch: FIx build failure with gcc7
* Tue May 24 2016 dimstar@opensuse.org
- Add htdig-unsigned-char.patch: use unsigned char to be sure we
  can store values up to (int)255.
* Tue Apr 21 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Update dependencies
- Update category for devel package
- rename htdig-README.SuSE to htdig-README.SUSE
* Sat Oct 15 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Thu Feb 26 2009 mseben@suse.cz
- added gmtime-lastday.patch - use INT32_MAX to define last day
  (bnc##231196), related to (bnc#343913)
* Wed Jan  9 2008 mskibbe@suse.de
- Bug 343913 - Package htdig-3.2.0b6-109: htsearch segfaults
* Mon Nov 12 2007 mskibbe@suse.de
- Bug 304239 - VUL-0: XSS in htsearch / htdig
* Tue Jul 31 2007 mskibbe@suse.de
- fix bug: htstat throwing SIGSEGV (#284282)
* Thu May 10 2007 lrupp@suse.de
- split htdig into -doc and -devel packages
- specfile cleanup
- build parallel
- enable openssl support
- enable bigfile support
- enable zlib
- remove static libs
- included patches from upstream:
  + htdig-ExternalParser-typo.patch (fix typo)
  + htdig-google-style.patch (layout fix for multiple result pages)
  + htdig-rundig.patch (fallback for missing common_dir in config)
  + htdig-simpleUTF8.patch (try to handle non UTF8 chars)
  + htdig-SSLConnection.patch (see
  http://sourceforge.net/mailarchive/forum.php?thread_id=5425639&forum_id=2688
  for details)
* Thu Mar 29 2007 ro@suse.de
- added zlib-devel to buildreq
* Fri Jan 12 2007 mskibbe@suse.de
- htdig-3.2.0b6-45: left shift count >= width of type (#231196)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Oct 13 2005 hvogel@suse.de
- removed some extra qualifications. Added
  * htsearch-gcc41.patch
* Tue Sep 27 2005 mmj@suse.de
- Fix strict aliasing issues
- Use %%patch to apply patches
* Thu Jan 27 2005 ke@suse.de
- Fix a cross site scripting flaw as found by Michael Krax; apply the
  patch proposed by Phil Knirsch; CAN-2005-0085 [# 50238].
* Thu Nov 11 2004 ro@suse.de
- fixed filelist
* Fri Aug 27 2004 ke@suse.de
- Improve htdig-README.SuSE.
- Drop obsolete notification message [# 44355].
* Tue Jul  6 2004 ke@suse.de
- Major update to version 3.2.0b6; most Suse supplied patches look
  obsolete.
* Mon Apr 26 2004 ro@suse.de
- build using apache2
* Thu Mar 25 2004 mmj@suse.de
- Add postfix to # neededforbuild
* Fri Mar  5 2004 ke@suse.de
- Do not call 'sed -i' on directories.
* Fri Feb 27 2004 ro@suse.de
- fix requires to /usr/local/bin/perl
* Tue Jan 13 2004 ke@suse.de
- Use /usr/sbin/apxs to make it built for non root users (thanks for
  hint to Peter Poeml).
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr
* Thu Jul 17 2003 pthomas@suse.de
- Add patch to enable passing file::/ URLs.
- Adapt configure.in of htdig and included libdb to autoconf 2.5X.
- Compile with full warnings enabled.
- Fix nearly all compiler warnings.
* Wed Jun 11 2003 kukuk@suse.de
- Add missing directories to filelist
* Wed Jun 11 2003 ke@suse.de
- For updating the config file use %%post instead of %%pre.
* Tue Jun 10 2003 ke@suse.de
- Move config file to /etc/htdig/htdig.conf; reported by Michal Svec
  [# 27080].
- Save old config file as /etc/htdig/htdig.conf.rpmorig.
* Wed May 28 2003 ke@suse.de
- Fix memory problem with htnotify [# 26913]; reported by Daniele
  Frijia.  Apply patch provided by Martin Kraemer;
  http://sourceforge.net/tracker/index.php?func=detail&aid=593091&group_id=4593&atid=304593
* Tue Apr 29 2003 freitag@suse.de
- fixed a 64-bit problem with htsearch, see Bug #26358,
  results in diff htsearch_64.patch
* Wed Apr 16 2003 coolo@suse.de
- use BuildRoot
* Tue Feb 11 2003 freitag@suse.de
- fixed location of the images of htdig in the conf file. They are
  now relative to the document root (Bug #15500)
* Wed Nov  6 2002 freitag@suse.de
- fixed broken patches
* Tue Nov  5 2002 freitag@suse.de
- fixed the README file ( Bug #20062)
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Mon Sep  9 2002 uli@suse.de
- increased DB_FILE_ID_LEN in DB2 to 24 to fit 64 bit __ino_t type
  on x86-64, ia64, s390x and ppc64
- enabled x86 spinlock implementation on x86-64
* Thu Aug  1 2002 ro@suse.de
- adapt server-root
* Wed Jun 19 2002 freitag@suse.de
- update to version 3.1.6, which
  * fixes some security wholes that were fixed by patches formerly
  * fixes many small bugs
  * brings tools to generate ascii databases
  * adds a bunch of new keywords
  The SuSE package now installs to other pathes, please read README.SuSE
  for further information.
* Tue Feb 19 2002 freitag@suse.de
- signed config files as %%conf in the spec file and fixed the
  filelist (Bug #12326)
* Wed Jan 23 2002 schwab@suse.de
- Fix for gcc3.
* Thu Aug 16 2001 utuerk@suse.de
- dropped 'out-of-date' notify [#6139]
- dropped unneeded dochost templates, left the originals [#9715]
* Tue May  8 2001 mfabian@suse.de
- bzip2 sources
* Fri Feb 23 2001 ro@suse.de
- changed neededforbuild <apache> to <apache apache-devel>
* Wed Jan 31 2001 freitag@suse.de
- fixed a typo in html-files
* Sun Jan 14 2001 kukuk@suse.de
- Add group tag
* Fri Sep  8 2000 schwab@suse.de
- Add ia64 support in db.
* Thu Apr 13 2000 ro@suse.de
- added mm to neededforbuild
* Wed Mar  8 2000 freitag@suse.de
- fixing wrong links to images on localhost
* Wed Mar  8 2000 freitag@suse.de
- fixing again some links, clearifying change losses
* Mon Mar  6 2000 freitag@suse.de
- removed entries from /usr/local/httpsd
* Sat Mar  4 2000 freitag@suse.de
- fixed layout on search pages
* Tue Feb 29 2000 freitag@suse.de
- update to version 3.1.5 - Security fixes.
* Mon Feb 21 2000 freitag@suse.de
- patches for using with kdevellop added
* Thu Feb 10 2000 freitag@suse.de
- new version 3.1.4
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon Jul 12 1999 ray@suse.de
- update to 3.1.2
* Wed Mar 17 1999 ro@suse.de
- diff cleanup
* Thu Jan 28 1999 ray@suse.de
- fix S.u.S.E -> SuSE ;)
* Sat Jan 16 1999 ray@suse.de
- fix /usr/local/bin/perl require
* Mon Dec  7 1998 ray@suse.de
- update docu
* Thu Nov  5 1998 ray@suse.de
- update to 3.1.0b2
* Mon Sep 14 1998 ro@suse.de
- update to 3.1.0b1
- cleanup: use original source and extra tar for suse-gif
* Tue Jun 16 1998 bs@suse.de
- fixed neededforbuild in spec file
* Wed May 13 1998 ray@suse.de
- fix for startpage (search.html)
* Mon Apr 20 1998 ro@suse.de
- fixed dependency for /usr/local/bin/perl
* Mon Mar 23 1998 ray@suse.de
- insert whole htdoc and contrib
* Wed Mar 11 1998 ray@suse.de
- fix (send mail to root)
* Tue Mar  3 1998 ray@suse.de
- new packages
- htdig  Version 3.0.8b2
